@@ -25,8 +25,8 @@ class Api(object):
         for index,item in enumerate(node_list):
             rest_client = RestClient(item["ip"])
             ret = rest_client.state.get_state()
-            state = ret["data"][0] if ret["state"] == 1 else "offline"
-            node_list[index]["state"] = state
+            node_list[index]["state"] = ret["data"][0] if ret["state"] == 1 else "offline"
+            node_list[index]["automation"] = ret["data"][4] if ret["state"] == 1 else "None"
         return node_list
 
     def set_project_name(self, node_ip, project_name):
